@@ -10,7 +10,7 @@ PPI::Document::Fragment - A fragment of a Perl Document
 
 In some situations you might want to work with a fragment of a larger
 document. C<PPI::Document::Fragment> is a class intended for this purpose.
-It is functionaly almost identical to a normal L<PPI::Document>, except
+It is functionally almost identical to a normal L<PPI::Document>, except
 that it is not possible to get line/column positions for the elements
 within it, and it does not represent a scope.
 
@@ -23,7 +23,7 @@ use base 'PPI::Document';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 
@@ -72,15 +72,15 @@ obvious would be to implement arbitrary cut/copy/paste more easily.
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
