@@ -76,7 +76,7 @@ use Params::Util '_INSTANCE';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 
@@ -117,7 +117,7 @@ The C<clone> method creates another instance of the same Find object.
 
 The cloning is done safely, so if your existing Find object is in the
 middle of an iteration, the cloned Find object will not also be in the
-iteration and can be safely used independantly.
+iteration and can be safely used independently.
 
 Returns a duplicate PPI::Find object.
 
@@ -218,7 +218,7 @@ sub in {
 
 =head2 start $Element
 
-The C<start> method lets the Find object act as an interator. The method
+The C<start> method lets the Find object act as an iterator. The method
 is passed the parent PPI::Element object as for the C<in> method, but does
 not accept any parameters.
 
@@ -289,7 +289,7 @@ sub match {
 
 =head2 finish
 
-The C<finish> method provides a mechanism to end interation if you wish to
+The C<finish> method provides a mechanism to end iteration if you wish to
 stop the iteration prematurely. It resets the Find object and allows it to
 be safely reused.
 
@@ -325,7 +325,7 @@ sub _execute {
 	my @queue  = ( $self->{in} );
 
 	# Pull entries off the queue and hand them off to the wanted function
-	while ( my $Element = shift @{$self->{queue}} ) {
+	while ( my $Element = shift @queue ) {
 		my $rv = &$wanted( $Element, $self->{in} );
 
 		# Add to the matches if returns true
@@ -346,8 +346,6 @@ sub _execute {
 		}
 	}
 
-	# Save the queue and return
-	$self->{queue} = \@queue;
 	1;
 }
 
@@ -383,15 +381,15 @@ sub _error {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
