@@ -58,7 +58,7 @@ use Params::Util    '_INSTANCE',
 
 use vars qw{$VERSION *_PARENT};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 	*_PARENT = *PPI::Element::_PARENT;
 }
 
@@ -520,8 +520,11 @@ returns C<undef> on error, which you probably B<should> test for.
 
 =begin testing prune 2
 
-my $document = PPI::Document->new( \<<'END_PERL' );
-#!/usr/bin/perl
+# Avoids a bug in old Perls relating to the detection of scripts
+# Known to occur in ActivePerl 5.6.1 and at least one 5.6.2 install.
+my $hashbang = reverse 'lrep/nib/rsu/!#'; 
+my $document = PPI::Document->new( \<<"END_PERL" );
+$hashbang
 
 use strict;
 
@@ -536,6 +539,7 @@ print "\n";
 
 exit;
 END_PERL
+
 isa_ok( $document, 'PPI::Document' );
 ok( defined($document->prune ('PPI::Statement::Sub')),
 	'Pruned multiple subs ok' );
@@ -715,7 +719,7 @@ sub __insert_before_child {
 	1;
 }
 
-# Replace a child
+# Insert one or more elements after a child
 sub __insert_after_child {
 	my $self = shift;
 	my $key  = refaddr shift;
@@ -786,15 +790,15 @@ sub __link_children {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
