@@ -155,7 +155,7 @@ use PPI::Statement::Variable       ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 # "Normal" statements end at a statement terminator ;
@@ -190,7 +190,7 @@ sub new {
 
 =head2 label
 
-One factor common to most statements is their ability to be labelled.
+One factor common to most statements is their ability to be labeled.
 
 The C<label> method returns the label for a statement, if one has been
 defined, but without the trailing colon. Take the following example
@@ -236,6 +236,20 @@ sub stable {
 #####################################################################
 # PPI::Element Methods
 
+# Is the statement complete.
+# By default for a statement, we need a semi-colon at the end.
+sub _complete {
+	my $self = shift;
+	my $semi = $self->schild(-1);
+	return !! (
+		$semi
+		and
+		$semi->isa('PPI::Token::Structure')
+		and
+		$semi->content eq ';'
+	);
+}
+
 # You can insert either a statement, or a non-significant token.
 sub insert_before {
 	my $self    = shift;
@@ -289,15 +303,15 @@ sub _Fragment {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
