@@ -37,7 +37,7 @@ use base 'PPI::Token';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 
@@ -130,14 +130,15 @@ sub __TOKENIZER__scan_for_end {
 	my $depth = 0;
 	while ( exists $t->{line} ) {
 		# Get the search area
-		$_ = $t->{line_cursor}
+		my $search_area
+			= $t->{line_cursor}
 			? substr( $t->{line}, $t->{line_cursor} )
 			: $t->{line};
 
 		# Look for a match
-		unless ( /^(.*?(?:\(|\)))/ ) {
+		unless ( $search_area =~ /^(.*?(?:\(|\)))/ ) {
 			# Load in the next line
-			$string .= $_;
+			$string .= $search_area;
 			return undef unless defined $t->_fill_line;
 			$t->{line_cursor} = 0;
 			next;
@@ -164,15 +165,15 @@ sub __TOKENIZER__scan_for_end {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
