@@ -27,11 +27,6 @@ in the various types that Perl supports.
 
 =head1 METHODS
 
-There are no additional methods beyond those provided by the parent
-L<PPI::Token> and L<PPI::Element> classes.
-
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
@@ -39,12 +34,39 @@ use base 'PPI::Token';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
+=head2 base
 
+The C<base> method is provided by all of the ::Number subclasses.
+This is 10 for decimal, 16 for hexadecimal, 2 for binary, etc.
 
+=cut
 
+sub base {
+	return 10;
+}
+
+=head2 literal
+
+Return the numeric value of this token.
+
+=cut
+
+sub literal {
+	my $self = shift;
+	return 0+$self->_literal;
+}
+
+sub _literal {
+	# De-sugar the string representation
+	my $self = shift;
+	my $str = $self->content;
+	$str =~ s/^\+//;
+	$str =~ s/_//g;
+	return $str;
+}
 
 #####################################################################
 # Tokenizer Methods
@@ -63,75 +85,31 @@ sub __TOKENIZER__on_char {
 	if ( $token->{content} =~ /^-?0_*$/ ) {
 		# This could be special
 		if ( $char eq 'x' ) {
-			$token->{_subtype} = 'hex';
+			$t->{class} = $t->{token}->set_class( 'Number::Hex' );
 			return 1;
 		} elsif ( $char eq 'b' ) {
-			$token->{_subtype} = 'binary';
+			$t->{class} = $t->{token}->set_class( 'Number::Binary' );
 			return 1;
 		} elsif ( $char =~ /\d/ ) {
-			$token->{_subtype} = 'octal';
-			return 1;
-		} elsif ( $char eq '.' ) {
-			return 1;
-		} else {
-			# End of the number... its just 0
-			return $t->_finalize_token->__TOKENIZER__on_char( $t );
-		}
-	}
-
-	if ( ! $token->{_subtype} or $token->{_subtype} eq 'base256' ) {
-		# Handle the easy case, integer or real.
-		return 1 if $char =~ /\d/o;
-
-		if ( $char eq '.' ) {
-			if ( $token->{content} =~ /\.$/ ) {
-				# We have a .., which is an operator.
-				# Take the . off the end of the token..
-				# and finish it, then make the .. operator.
-				chop $t->{token}->{content};
-				$t->_new_token('Operator', '..') or return undef;
-				return 0;
-			} else {
-				# Will this be the first .?
-				if ( $token->{content} =~ /\./ ) {
-					return 1;
-				} else {
-					# Flag as a base256.
-					$token->{_subtype} = 'base256';
-					return 1;
-				}
-			}
-		}
-
-	} elsif ( $token->{_subtype} eq 'octal' ) {
-		if ( $char =~ /\d/ ) {
 			# You cannot have 8s and 9s on octals
 			if ( $char eq '8' or $char eq '9' ) {
 				$token->{_error} = "Illegal character in octal number '$char'";
 			}
+			$t->{class} = $t->{token}->set_class( 'Number::Octal' );
 			return 1;
 		}
+	}
 
-	} elsif ( $token->{_subtype} eq 'hex' ) {
-		if ( $char =~ /\w/ ) {
-			unless ( $char =~ /[\da-f]/ ) {
-				# Add a warning if it contains non-hex chars
-				$token->{_error} = "Illegal character in hexidecimal number '$char'";
-			}
-			return 1;
-		}
+	# Handle the easy case, integer or real.
+	return 1 if $char =~ /\d/o;
 
-	} elsif ( $token->{_subtype} eq 'binary' ) {
-		if ( $char =~ /[\w\d]/ ) {
-			unless ( $char eq '1' or $char eq '0' ) {
-				# Add a warning if it contains non-hex chars
-				$token->{_error} = "Illegal character in binary number '$char'";
-			}
-			return 1;
-		}
-
-	} else {
-		Carp::croak("Unknown number type '$token->{_subtype}'");
+	if ( $char eq '.' ) {
+		$t->{class} = $t->{token}->set_class( 'Number::Float' );
+		return 1;
+	}
+	if ( $char eq 'e' || $char eq 'E' ) {
+		$t->{class} = $t->{token}->set_class( 'Number::Exp' );
+		return 1;
 	}
 
 	# Doesn't fit a special case, or is after the end of the token
@@ -143,24 +121,34 @@ sub __TOKENIZER__on_char {
 
 =pod
 
+=head1 CAVEATS
+
+Compared to Perl, the number tokenizer is too liberal about allowing
+underscores anywhere.  For example, the following is a syntax error in
+Perl, but is allowed in PPI:
+
+   0_b10
+
 =head1 TO DO
 
-- Add proper unit testing to this
+- Treak v-strings as binary strings or barewords, not as "base-256"
+  numbers
 
-- What the hell is a base256 number and why did I use it.
-  Surely it should be something more like "base1000" or "version".
+- Break out decimal integers into their own subclass?
+
+- Implement literal()
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
