@@ -8,7 +8,7 @@ PPI::Token::Symbol - A token class for variables and other symbols
 
 =head1 INHERITANCE
 
-  PPI::Token::Word
+  PPI::Token::Symbol
   isa PPI::Token
       isa PPI::Element
 
@@ -22,8 +22,8 @@ variables and other things that start with a sigil.
 This class has several methods beyond what is provided by its
 L<PPI::Token> and L<PPI::Element> parent classes.
 
-Most are provided to help work out what the object is actually pointing at,
-rather than what it might appear to be pointing at.
+Most methods are provided to help work out what the object is actually
+pointing at, rather than what it might appear to be pointing at.
 
 =cut
  
@@ -33,7 +33,7 @@ use Params::Util '_INSTANCE';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 
@@ -71,7 +71,7 @@ sub canonical {
 
 The C<symbol> method returns the ACTUAL symbol this token refers to.
 
-A token of C<$foo> might actually be refering to C<@foo>, if it is found
+A token of C<$foo> might actually be referring to C<@foo>, if it is found
 in the form C<$foo[1]>.
 
 This method attempts to resolve these issues to determine the actual
@@ -98,11 +98,11 @@ sub symbol {
 	my $braces = $after->braces;
 	return $symbol unless defined $braces;
 	if ( $type eq '$' ) {
-		return substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
-		return substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
+		substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
+		substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
 
 	} elsif ( $type eq '@' ) {
-		return substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
+		substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
 
 	}
 
@@ -113,8 +113,8 @@ sub symbol {
 
 =head2 raw_type
 
-The C<raw_type> method returns the apparent type of the symbol in the
-form of it's sigil.
+The C<raw_type> method returns the B<apparent> type of the symbol in the
+form of its sigil.
 
 Returns the sigil as a string.
 
@@ -129,8 +129,8 @@ sub raw_type {
 
 =head2 symbol_type
 
-The C<symbol_type> method returns the actual type of the symbol in the
-form of it's sigil.
+The C<symbol_type> method returns the B<actual> type of the symbol in the
+form of its sigil.
 
 Returns the sigil as a string.
 
@@ -161,7 +161,7 @@ sub __TOKENIZER__on_char {
 	# Handle magic things
 	my $content = $t->{token}->{content};	
 	if ( $content eq '@_' or $content eq '$_' ) {
-		$t->_set_token_class( 'Magic' );
+		$t->{class} = $t->{token}->set_class( 'Magic' );
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
@@ -172,7 +172,7 @@ sub __TOKENIZER__on_char {
 		if ( $nextchar eq '|' ) {
 			$t->{token}->{content} .= $nextchar;
 			$t->{line_cursor}++;
-			$t->_set_token_class( 'Magic' );
+			$t->{class} = $t->{token}->set_class( 'Magic' );
 		}
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
@@ -183,7 +183,7 @@ sub __TOKENIZER__on_char {
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 	if ( $content =~ /^(?:\$|\@)\d+/ ) {
-		$t->_set_token_class( 'Magic' );
+		$t->{class} = $t->{token}->set_class( 'Magic' );
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
@@ -193,7 +193,7 @@ sub __TOKENIZER__on_char {
 		(?: : (?!:) | # Allow single-colon non-magic vars
 			(?: \w+ | \' (?!\d) \w+ | \:: \w+ )
 			(?:
-				# Allow both :: and ' in namespace seperators
+				# Allow both :: and ' in namespace separators
 				(?: \' (?!\d) \w+ | \:: \w+ )
 			)*
 			(?: :: )? # Technically a compiler-magic hash, but keep it here
@@ -213,15 +213,15 @@ sub __TOKENIZER__on_char {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
