@@ -33,21 +33,21 @@ so on and so forth.
 
 =head1 METHODS
 
-Again, for the most part you should really B<need> to do anything very
-significant with whitespace.
+Again, for the most part you should really B<not> need to do anything
+very significant with whitespace.
 
 But there are a couple of convenience methods provided, beyond those
-provided by the parent L<PPI::Token> and L<PPI::Element>
-classes.
+provided by the parent L<PPI::Token> and L<PPI::Element> classes.
 
 =cut
 
 use strict;
 use base 'PPI::Token';
+use Clone ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 =pod
@@ -55,7 +55,7 @@ BEGIN {
 =head2 null
 
 Because PPI sees documents as sitting on a sort of substrate made of
-whitespace, there is a couple of corner cases that get particularly
+whitespace, there are a couple of corner cases that get particularly
 nasty if they don't find whitespace in certain places.
 
 Imagine walking down the beach to go into the ocean, and then quite
@@ -72,7 +72,12 @@ actual characters.
 
 =cut
 
-sub null { $_[0]->new('') }
+my $null = undef;
+
+sub null {
+	$null ||= $_[0]->new('');
+	Clone::clone($null);
+}
 
 ### XS -> PPI/XS.xs:_PPI_Token_Whitespace__significant 0.900+
 sub significant { '' }
@@ -85,15 +90,14 @@ C<tidy> is a convenience method for removing unneeded whitespace.
 
 Specifically, it removes any whitespace from the end of a line.
 
-Note that this B<doesn't> include in POD, where you may well need
+Note that this B<doesn't> include POD, where you may well need
 to keep certain types of whitespace. The entire POD chunk lives
-in it's own L<PPI::Token::Pod> object.
+in its own L<PPI::Token::Pod> object.
 
 =cut
 
 sub tidy {
-	my $self = shift;
-	$self->{content} =~ s/^\s+?(?>\n)//;
+	$_[0]->{content} =~ s/^\s+?(?>\n)//;
 	1;
 }
 
@@ -112,7 +116,7 @@ BEGIN {
 	foreach ( qw!; [ ] { } )! )                       { $COMMITMAP[ord $_] = 'PPI::Token::Structure' }
 	foreach ( 0 .. 9 )                                { $CLASSMAP[ord $_]  = 'Number'   }
 	foreach ( qw{= ? | + > . ! ~ ^} )                 { $CLASSMAP[ord $_]  = 'Operator' }
-	foreach ( qw{* $ @ & : - %} )                     { $CLASSMAP[ord $_]  = 'Unknown'  }
+	foreach ( qw{* $ @ & : %} )                       { $CLASSMAP[ord $_]  = 'Unknown'  }
 
 	# Miscellaneous remainder
 	$COMMITMAP[ord '#'] = 'PPI::Token::Comment';
@@ -130,23 +134,23 @@ BEGIN {
 
 sub __TOKENIZER__on_line_start {
 	my $t = $_[1];
-	$_ = $t->{line};
+	my $line = $t->{line};
 
 	# Can we classify the entire line in one go
-	if ( /^\s*$/ ) {
+	if ( $line =~ /^\s*$/ ) {
 		# A whitespace line
-		$t->_new_token( 'Whitespace', $t->{line} ) or return undef;
+		$t->_new_token( 'Whitespace', $line );
 		return 0;
 
-	} elsif ( /^\s*#/ ) {
+	} elsif ( $line =~ /^\s*#/ ) {
 		# Add the comment token, and finalize it immediately
-		$t->_new_token( 'Comment', $_ ) or return undef;
+		$t->_new_token( 'Comment', $line );
 		$t->_finalize_token;
 		return 0;
 
-	} elsif ( /^=(\w+)/ ) {
+	} elsif ( $line =~ /^=(\w+)/ ) {
 		# A Pod tag... change to pod mode
-		$t->_new_token( 'Pod', $t->{line} ) or return undef;
+		$t->_new_token( 'Pod', $line );
 		if ( $1 eq 'cut' ) {
 			# This is an error, but one we'll ignore
 			# Don't go into Pod mode, since =cut normally
@@ -162,15 +166,15 @@ sub __TOKENIZER__on_line_start {
 
 sub __TOKENIZER__on_char {
 	my $t = $_[1];
-	$_ = ord substr $t->{line}, $t->{line_cursor}, 1;
+	my $char = ord substr $t->{line}, $t->{line_cursor}, 1;
 
 	# Do we definately know what something is?
-	return $COMMITMAP[$_]->__TOKENIZER__commit($t) if $COMMITMAP[$_];
+	return $COMMITMAP[$char]->__TOKENIZER__commit($t) if $COMMITMAP[$char];
 
 	# Handle the simple option first
-	return $CLASSMAP[$_] if $CLASSMAP[$_];
+	return $CLASSMAP[$char] if $CLASSMAP[$char];
 
-	if ( $_ == 40 ) {  # $_ eq '('
+	if ( $char == 40 ) {  # $char eq '('
 		# Finalise any whitespace token...
 		$t->_finalize_token if $t->{token};
 
@@ -181,7 +185,7 @@ sub __TOKENIZER__on_char {
 		# 3. The one before that is a 'structure'
 
 		# Get the three previous significant tokens
-		my $tokens = $t->_previous_significant_tokens( 3 );
+		my $tokens = $t->_previous_significant_tokens(3);
 		if ( $tokens ) {
 			# A normal subroutine declaration
 			my $p1 = $tokens->[1];
@@ -215,7 +219,7 @@ sub __TOKENIZER__on_char {
 		# This is a normal open bracket
 		return 'Structure';
 
-	} elsif ( $_ == 60 ) { # $_ eq '<'
+	} elsif ( $char == 60 ) { # $char eq '<'
 		# Finalise any whitespace token...
 		$t->_finalize_token if $t->{token};
 
@@ -251,6 +255,9 @@ sub __TOKENIZER__on_char {
 		if ( $prev->isa('PPI::Token::Operator') and $prec eq '=' ) {
 			return 'QuoteLike::Readline';
 		}
+		if ( $prev->isa('PPI::Token::Operator') and $prec eq ',' ) {
+			return 'QuoteLike::Readline';
+		}
 
 		if ( $prev->isa('PPI::Token::Structure') and $prec eq '}' ) {
 			# Could go either way... do a regex check
@@ -267,7 +274,7 @@ sub __TOKENIZER__on_char {
 		# until this more comprehensive section was created.
 		return 'Operator';
 
-	} elsif ( $_ == 47 ) { #  $_ eq '/'
+	} elsif ( $char == 47 ) { #  $char eq '/'
 		# Finalise any whitespace token...
 		$t->_finalize_token if $t->{token};
 
@@ -339,7 +346,7 @@ sub __TOKENIZER__on_char {
 		# Add more tests here as potential cases come to light
 		return 'Operator';
 
-	} elsif ( $_ == 120 ) { # $_ eq 'x'
+	} elsif ( $char == 120 ) { # $char eq 'x'
 		# Handle an arcane special case where "string"x10 means the x is an operator.
 		# String in this case means ::Single, ::Double or ::Execute, or the operator versions or same.
 		my $nextchar = substr $t->{line}, $t->{line_cursor} + 1, 1;
@@ -353,7 +360,18 @@ sub __TOKENIZER__on_char {
 
 		# Otherwise, commit like a normal bareword
 		return PPI::Token::Word->__TOKENIZER__commit($t);
-	} elsif ( $_ >= 128 ) { # Outside ASCII
+
+	} elsif ( $char == 45 ) { # $char eq '-'
+		# Look for an obvious operator operand context
+		my $context = $t->_opcontext;
+		if ( $context eq 'operator' ) {
+			return 'Operator';
+		} else {
+			# More logic needed
+			return 'Unknown';
+		}
+
+	} elsif ( $char >= 128 ) { # Outside ASCII
             return 'PPI::Token::Word'->__TOKENIZER__commit($t) if $t =~ /\w/;
             return 'Whitespace' if $t =~ /\s/;
         }
@@ -361,7 +379,7 @@ sub __TOKENIZER__on_char {
 
 	# All the whitespaces are covered, so what to do
 	### For now, die
-	return $t->_error("Encountered unexpected character '$_'");
+	return $t->_error("Encountered unexpected character '$char'");
 }
 
 sub __TOKENIZER__on_line_end { $_[1]->_finalize_token if $_[1]->{token} }
@@ -372,15 +390,15 @@ sub __TOKENIZER__on_line_end { $_[1]->_finalize_token if $_[1]->{token} }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
