@@ -19,8 +19,8 @@ different types of word-like things, and is one of the most common Token
 classes found in typical documents.
 
 Specifically, it includes not only barewords, but also any other valid
-Perl identifier included non-operator keywords and core functions, and
-any can include C<::> separators inside it, as long as it fits the
+Perl identifier including non-operator keywords and core functions, and
+any include C<::> separators inside it, as long as it fits the
 format of a class, function, etc.
 
 =head1 METHODS
@@ -30,7 +30,8 @@ provided by its L<PPI::Token> and L<PPI::Element> parent
 classes.
 
 We expect to add additional methods to help further resolve a Word as
-a function, method, etc over time.
+a function, method, etc over time.  If you need such a thing right
+now, look at L<Perl::Critic::Utils>.
 
 =cut
 
@@ -39,7 +40,7 @@ use base 'PPI::Token';
 
 use vars qw{$VERSION %QUOTELIKE %OPERATOR};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 
 	%QUOTELIKE = (
 		'q'  => 'Quote::Literal',
@@ -57,6 +58,44 @@ BEGIN {
 	*OPERATOR = *PPI::Token::Operator::OPERATOR;
 }
 
+=head2 literal
+
+Returns the value of the Word as a string.  This assumes (often
+incorrectly) that the Word is a bareword and not a function, method,
+keyword, etc.  This differs from C<content> because C<Foo'Bar> expands
+to C<Foo::Bar>.
+
+=begin testing literal 9
+
+my @pairs = (
+	"F",          'F',
+	"Foo::Bar",   'Foo::Bar',
+	"Foo'Bar",    'Foo::Bar',
+);
+while ( @pairs ) {
+	my $from  = shift @pairs;
+	my $to    = shift @pairs;
+	my $doc   = PPI::Document->new( \"$from;" );
+	isa_ok( $doc, 'PPI::Document' );
+	my $word = $doc->find_first('Token::Word');
+	isa_ok( $word, 'PPI::Token::Word' );
+	is( $word->literal, $to, "The source $from becomes $to ok" );
+}
+
+=end testing 
+
+=cut
+
+sub literal {
+	my $self = shift;
+	my $word  = $self->content;
+
+	# Expand Foo'Bar to Foo::Bar
+	$word =~ s/\'/::/g;
+
+	return $word;
+}
+
 sub __TOKENIZER__on_char {
 	my $class = shift;
 	my $t     = shift;
@@ -83,20 +122,20 @@ sub __TOKENIZER__on_char {
 	# We might be a subroutine attribute.
 	my $tokens = $t->_previous_significant_tokens(1);
 	if ( $tokens and $tokens->[0]->{_attribute} ) {
-		$t->_set_token_class( 'Attribute' );
+		$t->{class} = $t->{token}->set_class( 'Attribute' );
 		return $t->{class}->__TOKENIZER__commit( $t );
 	}
 
 	# Check for a quote like operator
 	my $word = $t->{token}->{content};
 	if ( $QUOTELIKE{$word} and ! $class->__TOKENIZER__literal($t, $word, $tokens) ) {
-		$t->_set_token_class( $QUOTELIKE{$word} );
+		$t->{class} = $t->{token}->set_class( $QUOTELIKE{$word} );
 		return $t->{class}->__TOKENIZER__on_char( $t );
 	}
 
 	# Or one of the word operators
 	if ( $OPERATOR{$word} and ! $class->__TOKENIZER__literal($t, $word, $tokens) ) {
-	 	$t->_set_token_class( 'Operator' );
+	 	$t->{class} = $t->{token}->set_class( 'Operator' );
  		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
@@ -112,11 +151,11 @@ sub __TOKENIZER__on_char {
 	if ( $char eq ':' ) {
 		$t->{token}->{content} .= ':';
 		$t->{line_cursor}++;
-		$t->_set_token_class( 'Label' );
+		$t->{class} = $t->{token}->set_class( 'Label' );
 
 	# If not a label, '_' on its own is the magic filehandle
 	} elsif ( $word eq '_' ) {
-		$t->_set_token_class( 'Magic' );
+		$t->{class} = $t->{token}->set_class( 'Magic' );
 
 	}
 
@@ -301,15 +340,15 @@ sub __TOKENIZER__literal {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
