@@ -7,7 +7,7 @@ use base 'PPI::Token::_QuoteEngine';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.115';
+	$VERSION = '1.201';
 }
 
 
@@ -16,14 +16,14 @@ BEGIN {
 
 sub new {
 	my $class     = shift;
-	my $seperator = shift or return undef;
+	my $separator = shift or return undef;
 
-	# Create a new token containing the seperator
+	# Create a new token containing the separator
 	### This manual SUPER'ing ONLY works because none of
 	### Token::Quote, Token::QuoteLike and Token::Regexp
 	### implement a new function of their own.
-	my $self = PPI::Token::new( $class, $seperator ) or return undef;
-	$self->{seperator} = $seperator;
+	my $self = PPI::Token::new( $class, $separator ) or return undef;
+	$self->{separator} = $separator;
 
 	$self;
 }
@@ -33,8 +33,8 @@ sub _fill {
 	my $t     = shift;
 	my $self  = $t->{token} or return undef;
 
-	# Scan for the end seperator
-	my $string = $self->_scan_for_unescaped_character( $t, $self->{seperator} );
+	# Scan for the end separator
+	my $string = $self->_scan_for_unescaped_character( $t, $self->{separator} );
 	return undef unless defined $string;
 	if ( ref $string ) {
 		# End of file
@@ -53,15 +53,15 @@ sub _fill {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module
+See the L<support section|PPI/SUPPORT> in the main module.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
+Copyright 2001 - 2006 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
